# Polymatheia

![Validation Status](https://github.com/scmmmh/polymatheia/workflows/Validation/badge.svg) ![Build Status](https://github.com/scmmmh/polymatheia/workflows/Tests/badge.svg) [![Documentation Status](https://readthedocs.org/projects/polymatheia/badge/?version=latest)](https://polymatheia.readthedocs.io/en/latest/?badge=latest) [![PyPI version](https://badge.fury.io/py/polymatheia.svg)](https://badge.fury.io/py/polymatheia)

Polymatheia is a python library to support working with digital archive metadata. Its aim is not necessarily to cover
all ways of working with digital archive metadata, but to make it (comparatively) easy to undertake most types of
tasks and analysis.

*Homepage*: https://polymatheia.readthedocs.io

*Repository*: https://github.com/scmmmh/polymatheia

*Package*: https://pypi.org/project/polymatheia

*License*: MIT
